/* GmbSprite - a widget for Gnome Memory Blocks Sprite
 * (http://gnome-memblocks.sourceforge.net)
 *
 * Copyright (C) 2000 The Free Software Foundation
 *
 * Author: Volodymyr Babin <vb@dwuj.ichf.edu.pl>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#ifndef __GMB_SPRITE_ANIMATOR_H__
#define __GMB_SPRITE_ANIMATOR_H__

#include <gdk-pixbuf/gdk-pixbuf.h>
#include "gmb-sprite-area.h"

#define GMB_ANIMATION_TYPE        (gmb_animation_get_type ())
#define GMB_ANIMATION(o)          (GTK_CHECK_CAST ((o), GMB_ANIMATION_TYPE, GmbAnimation))
#define GMB_ANIMATION_CLASS(k)    (GTK_CHECK_CLASS_CAST ((k), GMB_ANIMATION_TYPE, GmbAnimationClass))
#define IS_GMB_ANIMATION(o)       (GTK_CHECK_TYPE ((o), GMB_ANIMATION_TYPE))
#define IS_GMB_ANIMATION_CLASS(k) (GTK_CHECK_CLASS_TYPE ((k), GMB_ANIMATION_TYPE))

typedef struct _GmbAnimation GmbAnimation;
typedef struct _GmbAnimationClass GmbAnimationClass;
typedef struct _GmbAnimationPrivat GmbAnimationPrivat;

struct _GmbAnimation
{
  GtkObject object;
  GmbAnimationPrivat * priv;
};

struct _GmbAnimationClass
{
  GtkObjectClass klass;
  /* signal */
  void (* bound_box_changed) (GmbAnimation *, guint, guint);
};

GtkType gmb_animation_get_type (void);
GmbAnimation * gmb_animation_new (void);
guint gmb_animation_get_n_frames (GmbAnimation *);
void gmb_animation_append_frame (GmbAnimation *,
				 GdkPixmap *,
				 GdkBitmap *,
				 guint16,
				 guint16,
				 guint);
void gmb_animation_prepend_frame (GmbAnimation *,
				  GdkPixmap *,
				  GdkBitmap *,
				  guint16,
				  guint16,
				  guint);
GmbAnimation * gmb_animation_new_from_gdk_pixbuf_animation (GdkPixbufAnimation *);

#define GMB_SPRITE_ANIMATOR_TYPE        (gmb_sprite_animator_get_type ())
#define GMB_SPRITE_ANIMATOR(o)          (GTK_CHECK_CAST ((o), GMB_SPRITE_ANIMATOR_TYPE, GmbSpriteAnimator))
#define GMB_SPRITE_ANIMATOR_CLASS(k)    (GTK_CHECK_CLASS_CAST ((k), GMB_SPRITE_ANIMATOR_TYPE, GmbSpriteAnimatorClass))
#define IS_GMB_SPRITE_ANIMATOR(o)       (GTK_CHECK_TYPE ((o), GMB_SPRITE_ANIMATOR_TYPE))
#define IS_GMB_SPRITE_ANIMATOR_CLASS(k) (GTK_CHECK_CLASS_TYPE ((k), GMB_SPRITE_ANIMATOR_TYPE))

typedef struct _GmbSpriteAnimator GmbSpriteAnimator;
typedef struct _GmbSpriteAnimatorClass GmbSpriteAnimatorClass;
typedef struct _GmbSpriteAnimatorPrivat GmbSpriteAnimatorPrivat;

typedef enum
{
  GMB_SPRITE_ANIMATOR_LOOP_NONE,
  GMB_SPRITE_ANIMATOR_LOOP_RESTART,
  GMB_SPRITE_ANIMATOR_LOOP_PING_PONG
} GmbSpriteAnimatorLoopType;

struct _GmbSpriteAnimator
{
  GmbSprite sprite;
  GmbSpriteAnimatorPrivat * priv;
};

struct _GmbSpriteAnimatorClass
{
  GmbSpriteClass klass;
  void (*playback_finished) (GmbSpriteAnimator *);
};

GtkType gmb_sprite_animator_get_type (void);
GmbSprite * gmb_sprite_animator_new (void);

void gmb_sprite_animator_set_animation (GmbSpriteAnimator *, GmbAnimation *);
const GmbAnimation * gmb_sprite_animator_get_animation (GmbSpriteAnimator *);

gboolean gmb_sprite_animator_is_reversed (const GmbSpriteAnimator *);
void gmb_sprite_animator_set_reversed (GmbSpriteAnimator *, gboolean);

GmbSpriteAnimatorLoopType gmb_sprite_animator_get_loop_type (const GmbSpriteAnimator *);
void gmb_sprite_animator_set_loop_type (GmbSpriteAnimator *, GmbSpriteAnimatorLoopType);

gdouble gmb_sprite_animator_get_playback_speed (const GmbSpriteAnimator *);
void gmb_sprite_animator_set_playback_speed (GmbSpriteAnimator *, gdouble);

gboolean gmb_sprite_animator_is_running (const GmbSpriteAnimator *);
void gmb_sprite_animator_start_playback (GmbSpriteAnimator *);
void gmb_sprite_animator_stop_playback (GmbSpriteAnimator *);

guint gmb_sprite_animator_get_animation_n_frames (GmbSpriteAnimator *);
void gmb_sprite_animator_advance (GmbSpriteAnimator *, gint);
void gmb_sprite_animator_goto_begin (GmbSpriteAnimator *);
void gmb_sprite_animator_goto_end (GmbSpriteAnimator *);

#endif	/* __GMB_SPRITE_ANIMATOR_H__ */
