/* GmbSprite - a widget for Gnome Memory Blocks
 * (http://gnome-memblocks.sourceforge.net)
 *
 * Copyright (C) 2000 The Free Software Foundation
 *
 * Author: Volodymyr Babin <vb@dwuj.ichf.edu.pl>
 *         Lots of GnomeCanvas event handling code has been used
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#ifndef __GMB_SPRITE_AREA_H__
#define __GMB_SPRITE_AREA_H__

#include <gtk/gtkwidget.h>

enum
{
  GMB_SPRITE_VISIBLE  = 1 << 4,
  GMB_SPRITE_REALIZED = 1 << 5,
};

#define GMB_SPRITE_TYPE        (gmb_sprite_get_type ())
#define GMB_SPRITE(o)          (GTK_CHECK_CAST ((o), GMB_SPRITE_TYPE, GmbSprite))
#define GMB_SPRITE_CLASS(k)    (GTK_CHECK_CLASS_CAST ((k), GMB_SPRITE_TYPE, GmbSpriteClass))
#define IS_GMB_SPRITE(o)       (GTK_CHECK_TYPE ((o), GMB_SPRITE_TYPE))
#define IS_GMB_SPRITE_CLASS(k) (GTK_CHECK_CLASS_TYPE ((k), GMB_SPRITE_TYPE))

typedef struct _GmbSprite GmbSprite;
typedef struct _GmbSpriteClass GmbSpriteClass;
typedef struct _GmbSpritePrivat GmbSpritePrivat;

struct _GmbSprite
{
  GtkObject object;
  /* host GmbSpriteArea (read-only) */
  struct _GmbSpriteArea * host;
  /* sprite area in host coordinates (read-only) */
  GdkRectangle area;
  GmbSpritePrivat * priv;
};

struct _GmbSpriteClass
{
  GtkObjectClass object_class;
  void (* size_request) (GmbSprite*, guint16 * width, guint16 * height);
  void (* realize) (GmbSprite*);
  void (* unrealize) (GmbSprite*);
  void (* paint) (GmbSprite*,
		  GdkDrawable*,
		  GdkRectangle*, /* clip area in host pixel coordinates */
		  GdkRectangle*); /* drawable area in host pixel coordinates */
  /* signal, event coordinates will in the host pixel coordinates */
  gint (* event) (GmbSprite*, GdkEvent*);
};

GtkType gmb_sprite_get_type (void);

#define GMB_SPRITE_AREA_TYPE        (gmb_sprite_area_get_type ())
#define GMB_SPRITE_AREA(o)          (GTK_CHECK_CAST ((o), GMB_SPRITE_AREA_TYPE, GmbSpriteArea))
#define GMB_SPRITE_AREA_CLASS(k)    (GTK_CHECK_CLASS_CAST ((k), GMB_SPRITE_AREA_TYPE, GmbSpriteAreaClass))
#define IS_GMB_SPRITE_AREA(o)       (GTK_CHECK_TYPE ((o), GMB_SPRITE_AREA_TYPE))
#define IS_GMB_SPRITE_AREA_CLASS(k) (GTK_CHECK_CLASS_TYPE ((k), GMB_SPRITE_AREA_TYPE))

typedef struct _GmbSpriteArea GmbSpriteArea;
typedef struct _GmbSpriteAreaClass GmbSpriteAreaClass;
typedef struct _GmbSpriteAreaPrivat GmbSpriteAreaPrivat;

struct _GmbSpriteArea
{
  GtkWidget widget;
  GmbSpriteAreaPrivat * priv;
};

struct _GmbSpriteAreaClass
{
  GtkWidgetClass widget_class;
};

GtkType gmb_sprite_area_get_type (void);

GtkWidget * gmb_sprite_area_new (void);

void gmb_sprite_area_freeze (GmbSpriteArea*);
void gmb_sprite_area_thaw (GmbSpriteArea*);
void gmb_sprite_area_flush (GmbSpriteArea*);

void gmb_sprite_area_add_sprite_top (GmbSpriteArea*, GmbSprite*, gint16 x, gint16 y);
void gmb_sprite_area_add_sprite_bottom (GmbSpriteArea*, GmbSprite*, gint16 x, gint16 y);

void gmb_sprite_raise (GmbSprite *);
void gmb_sprite_raise_to_top (GmbSprite *);
void gmb_sprite_lower (GmbSprite *);
void gmb_sprite_lower_to_bottom (GmbSprite *);

void gmb_sprite_show (GmbSprite*);
void gmb_sprite_hide (GmbSprite*);
void gmb_sprite_unparent (GmbSprite*);

void gmb_sprite_set_position (GmbSprite*, gint16 x, gint16 y);
void gmb_sprite_move (GmbSprite*, gint16 dx, gint16 dy);

typedef void (* GmbSpriteFunc) (GmbSprite *, gpointer);
void gmb_sprite_area_foreach (GmbSpriteArea *, GmbSpriteFunc, gpointer);

/* should only be used in particular sprite implementation */

void gmb_sprite_request_resize (GmbSprite*);
void gmb_sprite_area_request_update (GmbSpriteArea*, GdkRectangle*);

#endif /* __GMB_SPRITE_AREA_H__ */
